SafeFactoryContract class

Inheritance

Constructors

SafeFactoryContract({required ContractABI contract, required ETHAddress contractAddress, required SafeContractVersion version})

Properties

contract ContractABI
finalinherited
contractAddress ETHAddress
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version SafeContractVersion
final

Methods

calculateCreateProxyWithNonceAddress({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce}) Future<SafeContractEncodedCall>
Allows getting the address for a new proxy contract created via createProxyWithNonce. This method is only meant for address calculation purposes when you use an initializer that would revert. Therefore, the response is returned with a revert. When calling this method, set from to the address of the proxy factory.
override
createChainSpecificProxyWithNonce({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce}) Future<SafeContractEncodedCall>
Deploys a new chain-specific proxy with singleton singleton and saltNonce salt. Optionally executes an initializer call to a new proxy.
override
createChainSpecificProxyWithNonceL2({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce}) Future<SafeContractEncodedCall>
Deploys a new chain-specific proxy with singleton singleton and saltNonce salt. Optionally executes an initializer call to a new proxy.
override
createProxy({required ETHAddress masterCopy, required List<int> data}) Future<SafeContractEncodedCall>
Allows creating a new proxy contract and executing a message call to the new proxy within one transaction.
override
createProxyWithCallback({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce, required ETHAddress callback}) Future<SafeContractEncodedCall>
Allows to create a new proxy contract, execute a message call to the new proxy, and call a specified callback within one transaction.
override
createProxyWithNonce({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce}) Future<SafeContractEncodedCall>
Deploys a new proxy with singleton singleton and saltNonce salt. Optionally executes an initializer call to a new proxy.
override
createProxyWithNonceL2({required ETHAddress singleton, required List<int> initializer, required BigInt saltNonce}) Future<SafeContractEncodedCall>
Deploys a new proxy with singleton singleton and saltNonce salt. Optionally executes an initializer call to a new proxy.
override
decodeContractEvents(List<LogEntry> logs) List<SafeContractEvent>
inherited
encodeTransactionCall({required SafeContractFunction functionName, List<int>? selector, List<Object> params = const [], ONVALIDATEFUNCTION? onValidateFunction}) SafeContractEncodedCall
inherited
getChainId(EthereumProvider provider) Future<BigInt>
Returns the ID of the chain the contract is currently deployed on.
override
getEvents() List<SafeContractEventType>
inherited
getMethods() List<SafeContractFunction>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
proxyCreationCode(EthereumProvider provider) Future<List<int>>
Retrieve the {SafeProxy} creation code.
override
proxyRuntimeCode(EthereumProvider provider) Future<List<int>>
override
queryContract<T extends Object>({ONPARSECALLREQUEST<T>? onResponse, required SafeContractFunction functionName, required EthereumProvider provider, List<int>? selector, List<Object> params = const []}) Future<T>
inherited
resolveContractCreationMethod({required ETHAddress singleton, required List<int> initializer, BigInt? saltNonce, SafeCreationMode mode = SafeCreationMode.standard, SafeContractLayer layer = SafeContractLayer.l1, bool disableNonceForCreateProxy = false}) Future<SafeContractEncodedCall>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited