createProxy method

  1. @override
Future<SafeContractEncodedCall> createProxy({
  1. required ETHAddress masterCopy,
  2. required List<int> data,
})
override

Allows creating a new proxy contract and executing a message call to the new proxy within one transaction.

masterCopy Address of the master copy. data Payload for the message call sent to the new proxy contract.

Implementation

@override
Future<SafeContractEncodedCall> createProxy({
  required ETHAddress masterCopy,
  required List<int> data,
}) async {
  final params = [masterCopy, data];
  return encodeTransactionCall(
    functionName: SafeContractFunction.createProxy,
    params: params,
  );
}