createProxyWithCallback method

  1. @override
Future<SafeContractEncodedCall> createProxyWithCallback({
  1. required ETHAddress singleton,
  2. required List<int> initializer,
  3. required BigInt saltNonce,
  4. required ETHAddress callback,
})
override

Allows to create a new proxy contract, execute a message call to the new proxy, and call a specified callback within one transaction.

singleton Address of the master copy. initializer Payload for the message call sent to the new proxy contract. saltNonce Nonce that will be used to generate the salt to calculate the address of the new proxy contract. callback Callback that will be invoked after the new proxy contract has been successfully deployed and initialized.

Implementation

@override
Future<SafeContractEncodedCall> createProxyWithCallback({
  required ETHAddress singleton,
  required List<int> initializer,
  required BigInt saltNonce,
  required ETHAddress callback,
}) async {
  final params = [singleton, initializer, saltNonce, callback];
  return encodeTransactionCall(
    functionName: SafeContractFunction.createProxyWithCallback,
    params: params,
  );
}