BaseSafeContract class abstract mixin

Implementers

Constructors

BaseSafeContract()

Properties

contract ContractABI
final
contractAddress ETHAddress
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version SafeContractVersion
final

Methods

decodeContractEvents(List<LogEntry> logs) List<SafeContractEvent>
encodeTransactionCall({required SafeContractFunction functionName, List<int>? selector, List<Object> params = const [], ONVALIDATEFUNCTION? onValidateFunction}) SafeContractEncodedCall
getEvents() List<SafeContractEventType>
getMethods() List<SafeContractFunction>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryContract<T extends Object>({ONPARSECALLREQUEST<T>? onResponse, required SafeContractFunction functionName, required EthereumProvider provider, List<int>? selector, List<Object> params = const []}) Future<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited