Mixed-in types
Implementers
Methods
addOwnerWithThreshold ({required ETHAddress address , required int threshold })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Adds the owner owner to the Safe and updates the threshold to threshold.
approvedHashes ({required EthereumProvider provider , required ETHAddress address , required List <int > messageHash })
→ Future <bool >
"stateMutability": "view",
Returns a non-zero value if the messageHash is approved by the owner
approveHash (List <int > hashToApprove )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Marks hash hashToApprove as approved for msg.sender.
changeMasterCopy (ETHAddress masterCopy )
→ Future <SafeContractEncodedCall >
changeThreshold (int threshold )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Changes the threshold of the Safe to threshold.
checkNSignatures ({required List <int > dataHash , required List <int > data , required List <int > signatures , required BigInt requiredSignatures , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
Checks whether the provided signature is valid for the given hash.
Reverts if the signature is invalid.
checkNSignatures2 ({required ETHAddress address , required List <int > dataHash , required List <int > signatures , required BigInt requiredSignatures , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
Checks whether the provided signature is valid for the given hash.
Reverts if the signature is invalid.
checkSignatures ({required List <int > dataHash , required List <int > data , required List <int > signatures , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
Checks whether the signature provided is valid for the provided data and hash. Reverts otherwise.
checkSignatures2 ({required List <int > dataHash , required ETHAddress executor , required List <int > signatures , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
Checks whether the signature provided is valid for the provided data and hash and executor. Reverts otherwise.
decodeContractEvents (List <LogEntry > logs )
→ List <SafeContractEvent >
inherited
disableModule ({required ETHAddress prevModule , required ETHAddress module })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Disables the module module for the Safe.
domainSeparator (EthereumProvider provider )
→ Future <List <int > >
"stateMutability": "view",
Returns the domain separator for this contract, as defined in the EIP-712 standard.
domainSeparatorTypeHash (EthereumProvider provider )
→ Future <List <int > >
"stateMutability": "view",
The precomputed EIP-712 domain separator hash for Safe typed data hashing and signing.
enableModule (ETHAddress module )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Enables the module module for the Safe.
encodeTransactionCall ({required SafeContractFunction functionName , List <int > ? selector , List <Object > params = const [] , ONVALIDATEFUNCTION ? onValidateFunction })
→ SafeContractEncodedCall
inherited
encodeTransactionData ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation , required BigInt safeTxGas , required BigInt baseGas , required BigInt gasPrice , required ETHAddress gasToken , required ETHAddress refundReceiver , required BigInt nonce , required EthereumProvider provider })
→ Future <List <int > >
"stateMutability": "view",
Returns the pre-image of the Safe transaction hash.
Parameters:
execTransaction ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation , required BigInt safeTxGas , required BigInt baseGas , required BigInt gasPrice , required ETHAddress gasToken , required ETHAddress refundReceiver , required List <int > signatures })
→ Future <SafeContractEncodedCall >
"stateMutability": "payable",
Parameters:
execTransactionFromModule ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Executes an operation to to with native token value.
execTransactionFromModuleReturnData ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Executes an operation on the target address to with the specified
native token value, and returns the result data.
getChainId (EthereumProvider provider )
→ Future <BigInt >
Returns the ID of the chain the contract is currently deployed on.
getEvents ()
→ List <SafeContractEventType >
inherited
getMessageHash ({required EthereumProvider provider , required List <int > message })
→ Future <List <int > >
"stateMutability": "view",
Returns the hash of a message to be signed by owners.
getMethods ()
→ List <SafeContractFunction >
inherited
getModules (EthereumProvider provider )
→ Future <List <ETHAddress > >
"stateMutability": "view",
Returns array of first 10 modules.
getModulesPaginated ({required EthereumProvider provider , ETHAddress ? start , required int pageSize })
→ Future <(List <ETHAddress > , ETHAddress ) >
Returns an array of modules.
getOwners (EthereumProvider provider )
→ Future <List <ETHAddress > >
"stateMutability": "view",
Returns a list of Safe owners.
getStorageAt ({required EthereumProvider provider , required int offset , required int length })
→ Future <List <int > >
"stateMutability": "view",
length bytes of storage in the current contract
getThreshold (EthereumProvider provider )
→ Future <BigInt >
"stateMutability": "view",
Returns the number of required confirmations for a Safe transaction aka the threshold.
getTransactionHash ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation , required BigInt safeTxGas , required BigInt baseGas , required BigInt gasPrice , required ETHAddress gasToken , required ETHAddress refundReceiver , required BigInt nonce , required EthereumProvider provider })
→ Future <List <int > >
"stateMutability": "view",
Returns the transaction hash that must be signed by the Safe owners.
Parameters:
getVersion (EthereumProvider provider )
→ Future <String >
"stateMutability": "view",
Returns a descriptive version of the Safe contract.
isModuleEnabled ({required ETHAddress address , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
Returns whether or not a module is enabled.
isOwner ({required ETHAddress owner , required EthereumProvider provider })
→ Future <bool >
"stateMutability": "view",
if owner is an owner of the Safe.
isValidSignature ({required List <int > data , required List <int > signature })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
name (EthereumProvider provider )
→ Future <String >
"stateMutability": "view",
Returns a descriptive version of the Safe contract.
nonce (EthereumProvider provider )
→ Future <BigInt >
"stateMutability": "view",
Returns the nonce of the Safe contract.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryContract <T extends Object > ({ONPARSECALLREQUEST <T > ? onResponse , required SafeContractFunction functionName , required EthereumProvider provider , List <int > ? selector , List <Object > params = const [] })
→ Future <T >
inherited
removeOwner ({required ETHAddress prevOwner , required ETHAddress owner , required BigInt threshold })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Removes the specified owner from the Safe and updates the signature threshold.
requiredTxGas ({required ETHAddress to , required BigInt value , required List <int > data , required SafeContractExecutionOpration operation })
→ Future <SafeContractEncodedCall >
safeMsgTypeHash (EthereumProvider provider )
→ Future <List <int > >
"stateMutability": "view",
The precomputed EIP-712 type hash for the Safe message type.
safeTxTypeHash (EthereumProvider provider )
→ Future <List <int > >
"stateMutability": "view",
The precomputed EIP-712 type hash for the Safe transaction type.
sentinelModules (EthereumProvider provider )
→ Future <ETHAddress >
"stateMutability": "view",
The sentinel module value in the {ModuleManager.modules} linked list.
sentinelOwners (EthereumProvider provider )
→ Future <ETHAddress >
"stateMutability": "view",
The sentinel owner value in the {owners} linked list.
setFallbackHandler (ETHAddress handler )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Sets the fallback handler contract (handler) for the Safe.
setGuard (ETHAddress guard )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
A contract that manages transaction guards, which perform
pre- and post-execution checks on Safe transactions.
setModuleGuard (ETHAddress moduleGuard )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Sets the module guard (moduleGuard) for the Safe.
Make sure you trust the module guard before setting it.
setup ({required List <ETHAddress > owners , required BigInt threshold , required ETHAddress to , required List <int > data , required ETHAddress fallbackHandler , required ETHAddress paymentToken , required BigInt payment , required ETHAddress paymentReceiver })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Initializes the Safe account with its initial storage configuration.
signedMessages ({required EthereumProvider provider , required List <int > messageHash })
→ Future <bool >
"stateMutability": "view",
Returns a non-zero value if the messageHash is signed for the Safe.
signMessage (List <int > data )
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Can be verified using EIP-1271 validation method by passing the pre-image of the message hash and empty bytes as the signature.
simulateAndRevert ({required ETHAddress targetContract , required List <int > calldataPayload })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Executes a DELEGATECALL to the specified targetContract
within the context of the current contract (self).
swapOwner ({required ETHAddress prevOwner , required ETHAddress oldOwner , required ETHAddress newOwner })
→ Future <SafeContractEncodedCall >
"stateMutability": "nonpayable",
Replaces an existing owner (oldOwner) in the Safe with a new owner (newOwner).
toString ()
→ String
A string representation of this object.
inherited