EthereumSigner class abstract mixin

Implementers

Constructors

EthereumSigner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signAsync(List<int> message, {bool hashMessage = true}) Future<ETHSignature>
signPersonalMessageAsync(List<int> message, {int? payloadLength}) Future<List<int>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited