AccessEntry class

Represents an entry in the access list, specifying addresses and storage keys.

Constructors

AccessEntry({required ETHAddress address, required List<String> storageKeys})
const
AccessEntry.deserialize(List serialized)
Creates an AccessEntry from a serialized list of dynamic objects.
factory
AccessEntry.fromJson(Map<String, dynamic> json)
Creates an AccessEntry from a JSON map.
factory

Properties

address ETHAddress
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageKeys List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() List<List>
Serializes the access list entry to a list of dynamic objects.
toJson() Map<String, dynamic>
Converts the access list entry to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited