ethereum/src/models/models library
Classes
- AccessEntry
- Represents an entry in the access list, specifying addresses and storage keys.
- BlockDetails
- Represents details about an Ethereum block.
- BlockTag
- Represents block tag used in Ethereum JSON-RPC requests.
- BlockTagOrNumber
- Represents a block number or tag in Ethereum JSON-RPC requests.
- FeeHistorical
- Represents the historical fee levels with slow, normal, high, and base fee details.
- FeeHistory
- Represents the fee history in the context of Ethereum, including base fee per gas, gas used ratio, oldest block, and reward details.
- Filter
- Represents a filter configuration for Ethereum event logs.
- LogEntry
- Represents an entry in Ethereum transaction logs.
- TransactionInfo
- Represents information about an Ethereum transaction.
- TransactionReceipt
- Represents the receipt of an Ethereum transaction.
- Withdrawal
- Represents a withdrawal in the context of Ethereum block.