CborUnsignedValue class
A class representing a CBOR (Concise Binary Object Representation) int (64-byte) value.
- Inheritance
-
- Object
- CborObject
- CborNumeric
- CborUnsignedValue
- Available extensions
Constructors
- CborUnsignedValue.u32(int value)
-
factory
- CborUnsignedValue.u64(dynamic value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
An abstract property representing the dynamic value contained in the CBOR object.
finalinherited
- variables → List
-
no setteroverride
Methods
-
as<
T extends CborObject< (Object?> >[String? name]) → T -
Available on CborObject<
Object?> , provided by the QuickCborObject extension -
asMap<
T extends CborObject< (Object?> , E extends CborObject<Object?> >[String? name]) → CborMapValue< T, E> -
Available on CborObject<
Object?> , provided by the QuickCborObject extension -
cast<
E extends CborObject< (Object?> >) → E -
inherited
-
convertTo<
E, T extends CborObject< (Object?> >E toe(T e)) → E -
Available on CborObject<
Object?> , provided by the QuickCborObject extension -
encode(
) → List< int> -
Encode the value into CBOR bytes
override
-
getValue(
) → Object? -
override
-
hasType<
T> () → bool -
Available on CborObject<
Checks whether the value stored in theObject?> , provided by the QuickCborObject extensionCborObjecthas the specified typeT. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBigInt(
) → BigInt -
value as bigint
override
-
toCborHex(
) → String -
Encode the value into CBOR bytes an then to hex
override
-
toInt(
) → int -
value as int
override
-
toString(
) → String -
Returns the string representation of the value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited