value property
dynamic
value
finalinherited
An abstract property representing the dynamic value contained in the CBOR object.
Implementation
final T value;
An abstract property representing the dynamic value contained in the CBOR object.
final T value;