FragmentTypes enum

Inheritance
Available extensions

Values

constructor → const FragmentTypes

Constructor fragment type.

const FragmentTypes('constructor', [20])
event → const FragmentTypes

Event fragment type.

const FragmentTypes('event', [21])
function → const FragmentTypes

Function fragment type.

const FragmentTypes('function', [22])
fallback → const FragmentTypes

Fallback fragment type.

const FragmentTypes('fallback', [23])
error → const FragmentTypes

Error fragment type.

const FragmentTypes('error', [24])
receive → const FragmentTypes

Receive fragment type.

const FragmentTypes('receive', [25])

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromName(String? name) FragmentTypes
Retrieves a FragmentTypes instance based on its name (case-insensitive).
fromValue(List<int>? tags) FragmentTypes

Constants

values → const List<FragmentTypes>
A constant List of the values in this enum, in order of their declaration.