removeOwner method
Future<SafeContractEncodedCall>
removeOwner({
- required ETHAddress prevOwner,
- required ETHAddress owner,
- required BigInt threshold,
override
"stateMutability": "nonpayable",
Removes the specified owner from the Safe and updates the signature threshold.
This operation can only be performed through a Safe transaction.
Parameters:
prevOwner: The owner address that precedes theownerto be removed in the internal linked list of owners. If the owner to remove is the first (or only) element in the list,prevOwnermust be set to the sentinel address0x1(referred to asSENTINEL_OWNERSin the implementation).owner: The owner address to remove from the Safe.threshold: The new threshold value to apply after the removal.
Implementation
@override
Future<SafeContractEncodedCall> removeOwner({
required ETHAddress prevOwner,
required ETHAddress owner,
required BigInt threshold,
}) async {
final params = [prevOwner, owner, threshold];
return encodeTransactionCall(
functionName: SafeContractFunction.removeOwner,
params: params,
);
}