AuthorizationEntry class
Constructors
- AuthorizationEntry({required BigInt chainId, required ETHAddress address, required BigInt nonce, required ETHSignature signature})
-
const
- AuthorizationEntry.deserialize(List serialized)
-
Creates an AuthorizationEntry from a serialized list of dynamic objects.
factory
-
AuthorizationEntry.fromJson(Map<
String, dynamic> json) -
Creates an AuthorizationEntry from a JSON map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → List - Serializes the access list entry to a list of dynamic objects.
-
toJson(
) → Map< String, dynamic> - Converts the access list entry to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited