ZKSyncPaymaster class
Constructors
-
ZKSyncPaymaster({required ETHAddress address, required List<
int> input})
Properties
- address → ETHAddress
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → List< List> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited