ZksyncUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getTypeData({required BigInt chainId, required ETHAddress? from, required ETHAddress? to, required BigInt gasLimit, required BigInt maxFeePerGas, required int nonce, required ZKSyncE712Parameters zkParams, ETHTransactionType type = ETHTransactionType.eip712, Map<String, dynamic>? eip712Domain, BigInt? maxPriorityFeePerGas, BigInt? value, List<int>? data})
→ Eip712TypedData
-